# xnlbd
A Python package to study nonlinear beam dynamics phenomena in accelerator 
tracking simulations.

The package is designed to extend the tools and functionalities of xtrack by 
providing specific tools for analysing and visualising the nonlinear beam 
dynamics phenomena that emerge in tracking simulations carried out with xtrack 
(and other xsuite packages). The package provides functions to visualise highly 
nonlinear phase spaces by finding fixed points and separatrices, as well as to 
analyse the dynamics via normal forms and resonance driving terms.